<?php
/*============================================================*/
/* Набор основных функций для синтаксического разбора текста. */
/* Автор: Игорь Сергеевич Орещенков, февраль 2017 г.          */
/* Среда разработки: PHP 5.6.23 + AkelPad 4.9.7               */
/*============================================================*/
/*=====================================================================*/
/* Пропуск символов в строке.                                          */
/* Вызов: &$s - ссылка на обрабатываемую строку,                       */
/*        $t  - строка, содержащая пропускаемые символы,               */
/*        $p  - номер позиции в строке, с которой начинается обработка */
/*              (допускается FALSE в качестве конца строки),           */
/*        $l  - длина обрабатываемой строки.                           */
/* Возврат: номер позиции после пропущенных символов или               */
/*          FALSE, если достигнут конец строки.                        */
/*=====================================================================*/
function iaSkipOver (&$s, $t, $p = 0, $l = FALSE)
{
	if ($l === FALSE):
		$l = strlen ($s);
	endif;
	if ($p !== FALSE):
		while ($p < $l and strpos ($t, $s{$p}) !== FALSE):
			$p++;
		endwhile;
		if ($p >= $l):
			$p = FALSE;
		endif;
	endif;
	return $p;
}
/*=====================================================================*/
/* Поиск одного из символов в строке.                                  */
/* Вызов: &$s - ссылка на обрабатываемую строку,                       */
/*        $t  - строка, содержащая искомые символы,                    */
/*        $p  - номер позиции в строке, с которой начинается обработка */
/*              (допускается FALSE в качестве конца строки),           */
/*        $l  - длина обрабатываемой строки,                           */
/* Возврат: номер позиции первого найденного символа или               */
/*          FALSE, если достигнут конец строки.                        */
/*=====================================================================*/
function iaSkipTo (&$s, $t, $p = 0, $l = FALSE) {
	if ($l === FALSE):
		$l = strlen ($s);
	endif;
	if ($p !== FALSE):
		while ($p < $l and strpos ($t, $s{$p}) === FALSE):
			$p++;
		endwhile;
		if ($p >= $l):
			$p = FALSE;
		endif;
	endif;
	return $p;
}
?>